PENELOPE
========

Base classes
------------

.. automodule:: pypenelopetools.penelope.base
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:
    
.. automodule:: pypenelopetools.penelope.keyword
    :members:
    :undoc-members:
    :show-inheritance:
    
.. automodule:: pypenelopetools.penelope.separator
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pypenelopetools.penelope.input
    :members:
    :undoc-members:
    :show-inheritance:
    
.. automodule:: pypenelopetools.penelope.result
    :members:
    :undoc-members:
    :show-inheritance:

Keywords
--------

.. automodule:: pypenelopetools.penelope.keywords
    :members:
    :show-inheritance:

Separators
----------

.. automodule:: pypenelopetools.penelope.separators
    :members:
    :show-inheritance: